%?mingw_package_header

%global name1 sqlite

%global realver 3120200
%global rpmver 3.12.2.0

# bcond default logic is nicely backwards...
%bcond_with tcl
%global tclversion 8.5

Name:           mingw-%{name1}
Version:        %{rpmver}
Release:        %mkrel 6
Summary:        MinGW Windows port of sqlite embeddable SQL database engine

License:        Public Domain
Group:          Development/Other
URL:            http://www.sqlite.org/
Source0:        http://www.sqlite.org/2016/%{name1}-src-%{realver}.zip

BuildArch:      noarch

# Don't try to link against pthreads even if it is available
Patch1001:      sqlite-dont-search-for-pthreads-on-non-unix.patch

# Don't force build exe extension same as target exe extension
Patch1002:      sqlite-mingw-crosscompile.patch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-pdcurses
BuildRequires:  mingw32-readline
BuildRequires:  mingw32-termcap

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-pdcurses
BuildRequires:  mingw64-readline
BuildRequires:  mingw64-termcap

# For the pthread patch
BuildRequires:  autoconf automake libtool

BuildRequires:  tcl

%if %{with tcl}
BuildRequires:  /usr/bin/tclsh
BuildRequires:  mingw32-tcl
%endif


%description
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains cross-compiled libraries and development tools
for Windows.


# Win32
%package -n mingw32-%{name1}
Summary:        MinGW Windows port of sqlite embeddable SQL database engine
Requires:       pkgconfig

%description -n mingw32-%{name1}
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains cross-compiled libraries and development tools
for Windows.

%package -n mingw32-%{name1}-static
Summary:        Static version of MinGW Windows port of sqlite library
Requires:       mingw32-%{name1} = %{version}-%{release}
Group:          Development/Other

%description -n mingw32-%{name1}-static
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains static cross-compiled library

# Win64
%package -n mingw64-%{name1}
Summary:        MinGW Windows port of sqlite embeddable SQL database engine
Requires:       pkgconfig

%description -n mingw64-%{name1}
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains cross-compiled libraries and development tools
for Windows.

%package -n mingw64-%{name1}-static
Summary:        Static version of MinGW Windows port of sqlite library
Requires:       mingw64-%{name1} = %{version}-%{release}
Group:          Development/Other

%description -n mingw64-%{name1}-static
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains static cross-compiled library


%?mingw_debug_package


%prep
%setup -q -n %{name1}-src-%{realver}
%patch1001 -p0 -b .pthread
%patch1002 -p0 -b .cc
autoreconf -i --force


%build
# I think there's a bug in the configure script where, if
# cross-compiling, it cannot correctly determine the target executable
# extension (ie. .exe).  As a result it doesn't correctly detect that
# the target is Windows and so tries to use Unix-specific functions
# which don't exist.  In any case we can work around this by forcing
# the extension via this export.
#   - RWMJ 2008-09-30
export config_TARGET_EXEEXT=.exe
# add compile flags to enable rtree, fts3
export MINGW32_CFLAGS="%{mingw32_cflags} -DSQLITE_ENABLE_COLUMN_METADATA=1 -DSQLITE_DISABLE_DIRSYNC=1 -DSQLITE_ENABLE_FTS3=3 -DSQLITE_ENABLE_RTREE=1 -fno-strict-aliasing"
export MINGW64_CFLAGS="%{mingw64_cflags} -DSQLITE_ENABLE_COLUMN_METADATA=1 -DSQLITE_DISABLE_DIRSYNC=1 -DSQLITE_ENABLE_FTS3=3 -DSQLITE_ENABLE_RTREE=1 -fno-strict-aliasing"

%mingw_configure %{!?with_tcl:--disable-tcl} --enable-load-extension

# -lc hack
for i in build_win32 build_win64 ; do
    pushd $i
    sed -e s,build_libtool_need_lc=yes,build_libtool_need_lc=no, < libtool > libtool.x
    mv libtool.x libtool
    chmod a+x libtool
    popd
done

%mingw_make %{?_smp_mflags}


%install
%mingw_make_install DESTDIR=$RPM_BUILD_ROOT

chmod 0644 $RPM_BUILD_ROOT%{mingw32_libdir}/libsqlite3.dll.a
chmod 0644 $RPM_BUILD_ROOT%{mingw64_libdir}/libsqlite3.dll.a

%if %{with tcl}
install -d -m755 $RPM_BUILD_ROOT%{mingw32_datadir}/tcl%{tclversion}/sqlite3/
mv $RPM_BUILD_ROOT%{_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl $RPM_BUILD_ROOT%{mingw32_datadir}/tcl%{tclversion}/sqlite3/

install -d -m755 $RPM_BUILD_ROOT%{mingw64_datadir}/tcl%{tclversion}/sqlite3/
mv $RPM_BUILD_ROOT%{_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl $RPM_BUILD_ROOT%{mingw64_datadir}/tcl%{tclversion}/sqlite3/
%endif

# Drop all .la files
find $RPM_BUILD_ROOT -name "*.la" -delete

# Win32
%files -n mingw32-%{name1}
%doc README.md VERSION
%{mingw32_bindir}/sqlite3.exe
%{mingw32_bindir}/libsqlite3-0.dll
%{mingw32_libdir}/libsqlite3.dll.a
%{mingw32_includedir}/sqlite3.h
%{mingw32_includedir}/sqlite3ext.h
%{mingw32_libdir}/pkgconfig/sqlite3.pc
%if %{with tcl}
%{mingw32_datadir}/tcl%{tclversion}/sqlite3/
%{mingw32_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl
%endif

%files -n mingw32-%{name1}-static
%{mingw32_libdir}/libsqlite3.a

# Win64
%files -n mingw64-%{name1}
%doc README.md VERSION
%{mingw64_bindir}/sqlite3.exe
%{mingw64_bindir}/libsqlite3-0.dll
%{mingw64_libdir}/libsqlite3.dll.a
%{mingw64_includedir}/sqlite3.h
%{mingw64_includedir}/sqlite3ext.h
%{mingw64_libdir}/pkgconfig/sqlite3.pc
%if %{with tcl}
%{mingw64_datadir}/tcl%{tclversion}/sqlite3/
%{mingw64_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl
%endif

%files -n mingw64-%{name1}-static
%{mingw64_libdir}/libsqlite3.a




%changelog
* Wed May 11 2016 tv <tv> 3.12.2.0-6.mga6
+ Revision: 1012805
- new release

* Thu Feb 04 2016 umeabot <umeabot> 3.7.17-6.mga6
+ Revision: 934560
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.7.17-5.mga5
+ Revision: 743471
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.17-4.mga5
+ Revision: 682513
- Mageia 5 Mass Rebuild

* Sun Oct 27 2013 neoclust <neoclust> 3.7.17-3.mga4
+ Revision: 547472
- imported package mingw-sqlite

